ImageGenerationService class abstract
Abstract interface for AI image generation.
Implemented by Firebase AI's Imagen model. Consumed by neom_ia (SAIA) via Sint DI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateImage(
String prompt) → Future< Uint8List?> - Generates a single image from a text prompt.
-
generateImages(
String prompt, {int count = 1}) → Future< List< Uint8List> > - Generates multiple images from a text prompt.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited